@@ -9,6 +9,7 @@ class ErrorsCollector:
     def __init__(self):
         self._errors: List[Tuple[str, bool]] = []
         self.do_help: bool = False
+        self.show_errors: bool = True
 
     def add_error(self, msg: str, error_type: bool = False) -> None:
         self._errors.append((msg, error_type))
@@ -19,9 +20,15 @@ class ErrorsCollector:
     def set_do_help(self) -> None:
         self.do_help = True
 
+    def get_show_errors(self):
+        return self.show_errors
+
     def get_do_help(self) -> bool:
         return self.do_help
 
+    def unset_show_errors(self) -> None:
+        self.show_errors = False
+
     def yield_errors(self, error_type: bool = False) -> Generator[str, None, None]:
         for error in self._errors:
             if error[1] == error_type:
